//****************************************************************************
//  x10Demo.c
//  by RCI
//  This program Reads X10 Codes from PSC05 PowerLine Interface and Displays
//  House Code, Channel and Device ON/OFF on 2X16 Character Display.
//  It also Transmits X10 Data to PSC05 or PCS04.
//  Connect:
//           Any MCU         PSC05 Powerline Interface (Trans/Recieve)
//              A0              1          Zero Cross Detect
//              GND             2          Zero Cross Common
//              A1              3          Receive Output
//              A2              4          Transmit X10 Data
//
//           Any MCU          PSC04 Powerline Interface  (Transmit Only)
//              A0              1          Zero Cross Detect
//              Gnd             2          Zero Cross Common
//              Gnd             3          X10 Common
//              A1              4          Transmit X10 Signal
//
//  MCU - P16F887 (will work with most 16F and 18F processors).
//  Clock Freq. 8Mhz
//  Tested on EasyPIC5.
//  X10 Powerline Interface on PORTA,  Pulled High.
//  2X16 Character LCD on PORTB.
//  ON / OFF Test Push Buttons on PORTD.F0 and PORTD.F1, Pulled High
//
//  Apr 13, 2011
//
//****************************************************************************
#include "delay.h"
#include "x10.h"
//*** Variable Declarations***************************************************
#define ON 20
#define OFF 28
  // Lcd pinout settings
sbit LCD_RS at RB4_bit;   // LCD Pin 4
sbit LCD_EN at RB5_bit;   // LCD Pin 6
sbit LCD_D4 at RB0_bit;   // LCD Pin 11
sbit LCD_D5 at RB1_bit;   // LCD Pin 12
sbit LCD_D6 at RB2_bit;   // LCD Pin 13
sbit LCD_D7 at RB3_bit;   // LCD Pin 14

// Pin direction
sbit LCD_RS_Direction at TRISB4_bit;
sbit LCD_EN_Direction at TRISB5_bit;
sbit LCD_D7_Direction at TRISB3_bit;
sbit LCD_D6_Direction at TRISB2_bit;
sbit LCD_D5_Direction at TRISB1_bit;
sbit LCD_D4_Direction at TRISB0_bit;
extern char x10_read_bits(void);
char txt[4], trans[4];
//****************************************************************************
void DisplayMess1()
{
  LCD_Out(1, 1, "HC  Dev  On/Off ");
}
//****************************************************************************
void DisplayMess2()
{
  LCD_Out(2, 1, "House 'A' Ch 10 ");
}
//****************************************************************************
void DisplayMess3()
{
  LCD_Out(2, 1, "                ");
}
//****************************************************************************
void main()
{
          //  76543210
  ANSEL  =  0b00000000;
  ANSELH =  0b00000000;
  ADCON1 =  0b00000000;
  PORTA =   0b00000000;       //  Start with Everything Low
  PORTB =   0b00000000;       //  Start with Everything Low
  PORTC =   0b00000000;       //  Start with Everything Low
  PORTD =   0b00000000;       //  Start with Everything Low
  TRISA =   0b00000101;
  TRISB =   0b00000000;
  TRISC =   0b10111101;
  TRISD =   0b11111111;
  TRISE =   0b00000111;
  Lcd_Init();                 // Initialize LCD EasyPIC5
  LCD_Cmd(_LCD_CLEAR);        // Clear display
  LCD_Cmd(_LCD_CURSOR_OFF);   // Turn cursor off
  Delay1000ms();
               //1234567890123456
  LCD_Out(1, 1, "X10 Demo Program");
  LCD_Out(2, 1, "for P16F887     ");
  Delay2000ms();
  DisplayMess1();
  DisplayMess3();

//****************************************************************************
  while (1 == 1)
  {
  if (PORTD.F0 == 0)
    {
    while (PORTD.F0 == 0)
    {
    }
    LCD_Out(1, 1, "X10 Transmit ON ");
    DisplayMess2();
    x10Trans('A', 10, ON);    // House codes A - P,  Channels 0 - 15
    Delay1000ms();
    DisplayMess1();
    DisplayMess3();
    }
  if (PORTD.F1 == 0)
    {
    while (PORTD.F1 == 0)
    {
    }
    LCD_Out(1, 1, "X10 Transmit OFF");
    DisplayMess2();
    x10Trans('A', 10, OFF);   // House codes A - P,  Channels 0 - 15
    Delay1000ms();
    DisplayMess1();
    DisplayMess3();
    }
    Display_X10(2, 1, 3, 8);  // Reads and Displays X10 Data
   } // End While
} // End Main
//****************************************************************************